@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.24';
+our $VERSION = '0.2.25';
 
 1;
 
@@ -18,6 +18,7 @@ use File::Temp qw/ tempfile /;
 use Outthentic::Story;
 use Term::ANSIColor;
 use Hash::Merge qw{merge};
+use Time::localtime;
 
 my $config; 
 
@@ -165,7 +166,11 @@ sub run_story_file {
 
     my $task_name = get_prop('task_name');
 
-    note("\n". ( nocolor() ? short_story_name($task_name) : colored(['yellow'],short_story_name($task_name)) ));
+    note(
+      "\n". 
+      ( nocolor() ? short_story_name($task_name) : colored(['yellow'],short_story_name($task_name)) ).
+      ' at '.timestamp()
+    );
 
     if ( get_stdout() ){
 
@@ -207,7 +212,13 @@ sub run_story_file {
               $story_command = "ruby -I $ruby_lib_dir -r outthentic -I ".story_cache_dir()." $story_file";
             }
 
-        }elsif(-f "$story_dir/story.bash") {
+        }elsif(-f "$story_dir/story.py") {
+
+            my $python_lib_dir = File::ShareDir::dist_dir('Outthentic');
+            $story_command  = "PYTHONPATH=\$PYTHONPATH:".(story_cache_dir()).
+            ":$python_lib_dir python $story_dir/story.py";
+
+        } elsif(-f "$story_dir/story.bash") {
 
             my $bash_lib_dir = File::ShareDir::dist_dir('Outthentic');
             $story_command = "bash -c 'source ".story_cache_dir()."/glue.bash";
@@ -339,7 +350,7 @@ sub print_meta {
 
     my $task_name = get_prop('task_name');
 
-    note( "\n".( nocolor() ? short_story_name($task_name) : colored( ['yellow'], short_story_name($task_name) ) ));
+    note( ( nocolor() ? short_story_name($task_name) : colored( ['yellow'], short_story_name($task_name) ) ));
 
     while (my $i = <META>){
         chomp $i;
@@ -352,8 +363,7 @@ sub print_meta {
 
 sub short_story_name {
 
-
-    my $task_name = shift;
+    my $task_name = shift||"[s]";
     my $story_dir = get_prop('story_dir');
 
     my $cwd_size = scalar(split /\//, get_prop('project_root_dir'));
@@ -368,11 +378,20 @@ sub short_story_name {
     }
 
     my $story_vars = story_vars_pretty();
+
+
     return $task_name ? 
-      ( $task_name.' '.$short_story_dir.( $story_vars  ? " params: $story_vars" : "" )) :
+      ( $task_name.($short_story_dir ? ' '.$short_story_dir : '').( $story_vars  ? " params: $story_vars" : "" )) :
       $short_story_dir.( $story_vars  ? " params: $story_vars" : "" );
 }
 
+sub timestamp {
+  sprintf '%02d-%02d-%02d %02d:%02d:%02d', 
+    localtime->year()+1900, 
+    localtime->mon()+1, localtime->mday, 
+    localtime->hour, localtime->min, localtime->sec;
+}
+
 END {
 
   exit(1) unless $STATUS;
@@ -426,13 +445,6 @@ Perl scenario example:
     print "I am OK\n";
     print "I am outthentic\n";
 
-Ruby scenario example:
-
-    $ cat story.rb
-    
-    puts "I am OK"
-    puts "I am outthentic"
-
 Bash scenario example:
 
     $ cat story.bash
@@ -440,7 +452,21 @@ Bash scenario example:
     echo I am OK
     echo I am outthentic
 
-Outthentic scenarios could be written on one of three languages:
+Python scenario example:
+
+    $ cat story.py
+    
+    print "I am OK"
+    print "I am outthentic"
+
+Ruby scenario example:
+
+    $ cat story.rb
+    
+    puts "I am OK"
+    puts "I am outthentic"
+
+Outthentic scenarios could be written on one of four languages:
 
 =over
 
@@ -451,12 +477,17 @@ Perl
 
 =item *
 
-Ruby
+Bash
 
 
 =item *
 
-Bash
+Python
+
+
+=item *
+
+Ruby
 
 
 =back
@@ -471,8 +502,9 @@ This is the table to describe language / file name conventions:
     | Language  | File         |
     +-----------+--------------+
     | Perl      | story.pl     |
-    | Ruby      | story.rb     |
     | Bash      | story.bash   |
+    | Python    | story.py     |
+    | Ruby      | story.rb     |
     +-----------+--------------+
 
 
@@ -528,13 +560,17 @@ Just create a new directories with a story data inside:
     $ echo 'print "hello from perl";' > perl-story/story.pl
     $ echo 'hello from perl' > perl-story/story.check
     
-    $ mkdir ruby-story
-    $ echo 'puts "hello from ruby"' > ruby-story/story.rb
-    $ echo 'hello from ruby' > ruby-story/story.check
-    
     $ mkdir bash-story
     $ echo 'echo hello from bash' > bash-story/story.bash
     $ echo 'hello from bash' > bash-story/story.check
+    
+    $ mkdir python-story
+    $ echo 'print "hello from python"' > python-story/story.rb
+    $ echo 'print from python' > python-story/story.check
+    
+    $ mkdir ruby-story
+    $ echo 'puts "hello from ruby"' > ruby-story/story.rb
+    $ echo 'hello from ruby' > ruby-story/story.check
 
 Now, let's use C<strun> command to run suite stories:
 
@@ -777,6 +813,11 @@ You may inline code from other language to add some extra logic into your check
     echo 'this is debug message will be shown at console'
     CODE
     
+    code: <<CODE
+    !python
+    print 'this is debug message will be shown at console'
+    CODE
+    
     code: <<CODE
     !ruby
     puts 'this is debug message will be shown at console'
@@ -827,6 +868,16 @@ Perl:
     
     CODE
 
+Python:
+
+    generator: <<CODE
+    !python
+    print 'say'
+    print 'hello'
+    print 'again'
+    
+    CODE
+
 Ruby:
 
     generator: <<CODE
@@ -923,12 +974,17 @@ Perl
 
 =item *
 
-Ruby
+Bash
 
 
 =item *
 
-Bash
+Python
+
+
+=item *
+
+Ruby
 
 
 =back
@@ -939,8 +995,9 @@ Here is naming convention for hook files:
     | Language  | File         |
     +-----------+--------------+
     | Perl      | hook.pl      |
-    | Ruby      | hook.rb      |
     | Bash      | hook.bash    |
+    | Python    | hook.py      |
+    | Ruby      | hook.rb      |
     +-----------+--------------+
 
 Reasons why you might need a hooks:
@@ -1001,12 +1058,15 @@ Here is C<set_stdout()> function signatures list for various languages:
     | Language  | signature             |
     +-----------+-----------------------+
     | Perl      | set_stdout(SCALAR)    |
-    | Ruby      | set_stdout(STRING)    |
     | Bash      | set_stdout(STRING)    |
+    | Python(*) | set_stdout(STRING)    |
+    | Ruby      | set_stdout(STRING)    |
     +-----------+-----------------------+
 
 IMPORTANT: You should only use a set_stdout inside story hook, not scenario file.
 
+(*) you need to C<from outthentic import *> in Python to import set_stdout function.
+
 
 =head2 Upstream and downstream stories
 
@@ -1137,6 +1197,11 @@ Or using Ruby:
     
     run_story  'greeting', {  'name' => 'Alexey' , 'message' => 'hello' }
 
+Or using Python:
+
+    from outthentic import *
+    run_story('greeting', {  'name' : 'Alexey' , 'message' : 'hello' })
+
 Or Bash:
 
     $ cat hook.bash
@@ -1149,29 +1214,41 @@ Here is the C<run_story> signature list for various languages:
     | Language  | signature                                    |
     +-----------+----------------------------------------------+
     | Perl      | run_story(SCALAR,HASHREF)                    |
-    | Ruby      | run_story(STRING,HASH)                       | 
     | Bash      | run_story(STORY_NAME NAME VAL NAME2 VAL2 ... | 
+    | Python    | run_story(STRING,DICT)                       | 
+    | Ruby      | run_story(STRING,HASH)                       | 
     +-----------+----------------------------------------------+
 
-Story variables are accessible via C<story_var()> function. For example:
+Story variables are accessible via C<story_var()> function. 
+
+Examples:
+
+In Perl:
+
+    $ cat modules/greeting/story.pl
+    
+    print story_var('name'), 'say ', story_var('message');
+
+In Python:
+
+    $ cat modules/greeting/story.py
+    
+    from outthentic import *
+    print story_var('name') + 'say ' + story_var('message')
+
+In Ruby:
 
     $ cat modules/greeting/story.rb
     
     puts "#{story_var('name')} say #{story_var('message')}"
 
-Or if you use Perl:
-
-    $ cat modules/greeting/story.pl
-    
-    print (story_var('name')).'say '.(story_var('message'))
-
-Or finally Bash (1-st way):
+In Bash (1-st way):
 
     $ cat modules/greeting/story.bash
     
     echo $name say $message
 
-Bash (2-nd way):
+In Bash (2-nd way):
 
     $ cat modules/greeting/story.bash
     
@@ -1203,11 +1280,14 @@ Here is the how you access story variable in all three languages
     | Language         | signature                                   |
     +------------------+---------------------------------------------+
     | Perl             | story_var(SCALAR)                           |
+    | Python(*)        | story_var(STRING)                           | 
     | Ruby             | story_var(STRING)                           | 
     | Bash (1-st way)  | $foo $bar ...                               |
     | Bash (2-nd way)  | $(story_var foo.bar)                        |
     +------------------+---------------------------------------------+
 
+(*) you need to C<from outthentic import *> in Python to import story_var() function.
+
 
 =head2 Story properties
 
@@ -1245,8 +1325,12 @@ Outthentic provides some helpers and variables:
     +------------------+-----------------------------------------------------+
     | Perl             | function | os() | get a name of OS distribution     |
     | Bash             | variable | os   | get a name of OS distribution     |
+    | Python(*)        | function | os() | get a name of OS distribution     |
+    | Ruby             | function | os() | get a name of OS distribution     |
     +------------------+-----------------------------------------------------+
 
+(*) you need to C<from outthentic import *> in Python to import os() function.
+
 
 =head2 Meta stories
 
@@ -1292,10 +1376,28 @@ You may also call meta stories as downstream stories:
 Every story is a script gets executed and thus returning an exit code. If exit code is bad (!=0)
 this is treated as story verification failure. 
 
-Use C<ignore_story_err()> function to ignore unsuccessful story code:
+Use C<ignore_story_err(int)> function to ignore unsuccessful story code:
 
-    $ cat hook.rb
+    # Python
     
+    $ cat hook.py
+    from outthentic import *
+    ignore_story_err(1)
+    
+    
+    # Ruby
+    
+    $ cat hook.rb
+    ignore_story_err 1
+    
+    # Perl
+    
+    $ cat hook.pl
+    ignore_story_err(1)
+    
+    # Bash
+    
+    $ cat hook.bash
     ignore_story_err 1
 
 
@@ -1336,10 +1438,12 @@ Here is the list for library file names for various languages:
     | Language  | file            |
     +-----------+-----------------+
     | Perl      | common.pm       |
-    | Ruby      | common.rb       |
     | Bash      | common.bash     |
+    | Ruby      | common.rb       |
     +-----------+-----------------+
 
+B<I<NOTE!>>  Story libraries are not supported for Python
+
 
 =head1 Language libraries
 
@@ -1577,13 +1681,6 @@ for example in story hook file:
 
 Examples for other languages:
 
-Ruby:
-
-    $ cat hook.rb
-    
-    foo = config['main']['foo']
-    bar = config['main']['bar']
-
 Bash:
 
     $ cat hook.bash
@@ -1591,6 +1688,23 @@ Bash:
     foo=$(config main.foo )
     bar=$(config main.bar )
 
+Python:
+
+    $ cat hook.py
+    
+    
+    from outthentic import *
+    
+    foo = config()['main']['foo']
+    bar = config()['main']['bar']
+
+Ruby:
+
+    $ cat hook.rb
+    
+    foo = config['main']['foo']
+    bar = config['main']['bar']
+
 
 =head1 Runtime configuration
 
